OiRA

Help

1. Undirbúningur
3. Greining + Mat
4. Aðgerðaáætlun
5. Skýrsla
6. Staða 0%

# Lagaðu áhættumatið að fyrirtæki þínu

Til að geta hannað áhættumatið að fyrirtæki þínu þarft þú hugsanlega að svara eftirfarandi spurningum:

- Veldu (eða slepptu) hvort lýsing á starfseminni eigi við eða ekki, eftir því sem við á.
- Teldu upp rekstrareiningar, s.s. útibú eða verslanir o.s.frv. Forritið býr til áhættuflokka, sem verða endurteknir fyrir hverja einingu sem þú hefur valið.

## Commercial manned guarding

Does your organisation provide commercial manned guarding? Yes No
Do you offer this service in multiple locations? Yes No
Please enter a name for the location you would like to assess. Please enter the name for each location you would like to assess.

## Mobile partrolling/intervention after alarm

Does your organisation provide mobile patrolling / intervention after alarm? Yes No
Do you offer this service in multiple locations? Yes No
Please enter a name for the location you would like to assess. Please enter the name for each location you would like to assess.

## Event security

Does your organisation provide event security? Yes No
Do you offer this service in multiple locations? Yes No
Please enter a name for the location you would like to assess. Please enter the name for each location you would like to assess.

Scroll to top
Back

## profiling.html

Meira

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More